@@ -138,9 +138,10 @@ def geos_multipoint_from_py(ob):
         assert n == 2 or n == 3
 
         # Make pointer to the coordinate array
-        try:
+        if isinstance(array['data'], tuple):
+            # numpy tuple (addr, read-only)
             cp = cast(array['data'][0], POINTER(c_double))
-        except ArgumentError:
+        else:
             cp = array['data']
 
         # Array of pointers to sub-geometries
