@@ -124,15 +124,24 @@ class InteriorRingSequence(object):
     def __len__(self):
         return lgeos.GEOSGetNumInteriorRings(self._geom)
 
-    def __getitem__(self, i):
-        M = self.__len__()
-        if i + M < 0 or i >= M:
-            raise IndexError("index out of range")
-        if i < 0:
-            ii = M + i
+    def __getitem__(self, key):
+        m = self.__len__()
+        if isinstance(key, int):
+            if key + m < 0 or key >= m:
+                raise IndexError("index out of range")
+            if key < 0:
+                i = m + key
+            else:
+                i = key
+            return self._get_ring(i)
+        elif isinstance(key, slice):
+            res = []
+            start, stop, stride = key.indices(m)
+            for i in xrange(start, stop, stride):
+                res.append(self._get_ring(i))
+            return res
         else:
-            ii = i
-        return self._get_ring(i)
+            raise TypeError("key must be an index or slice")
 
     @property
     def _longest(self):
