@@ -3,7 +3,7 @@ from unittest import TestSuite
 import test_doctests, test_prepared, test_equality, test_geomseq, test_xy
 import test_collection, test_emptiness, test_singularity, test_validation
 import test_mapping, test_delegated, test_dlls, test_linear_referencing
-import test_products_z, test_box, test_speedups, test_cga
+import test_products_z, test_box, test_speedups, test_cga, test_getitem
 
 def test_suite():
     suite = TestSuite()
@@ -24,5 +24,6 @@ def test_suite():
     suite.addTest(test_box.test_suite())
     suite.addTest(test_speedups.test_suite())
     suite.addTest(test_cga.test_suite())
+    suite.addTest(test_getitem.test_suite())
     return suite
 
